.. _compute_pvalue:

`compute_pvalue`
================

.. automodule:: oasis_stat
   :members: compute_pvalue
   :undoc-members:
   :show-inheritance:
   :noindex:
   
Description
-----------
Computes p-value